=== modified file 'NEWS'
--- NEWS	2007-11-30 22:43:21 +0000
+++ NEWS	2007-12-01 11:43:56 +0000
@@ -14,6 +14,9 @@
 
   BUGFIXES:
 
+   * Better error message when running ``bzr cat`` on a non-existant branch.
+     (Lukáš Lalinský, #133782)
+
    * Catch ShortReadvErrors while using pycurl. Also make readv more robust by
      allowing multiple GET requests to be issued if too many ranges are
      required.

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-11-29 18:41:01 +0000
+++ bzrlib/builtins.py	2007-12-01 11:43:56 +0000
@@ -2114,22 +2114,15 @@
     def run(self, filename, revision=None, name_from_revision=False):
         if revision is not None and len(revision) != 1:
             raise errors.BzrCommandError("bzr cat --revision takes exactly"
-                                        " one number")
-        tree = None
-        try:
-            tree, b, relpath = \
-                    bzrdir.BzrDir.open_containing_tree_or_branch(filename)
-        except errors.NotBranchError:
-            pass
-
-        if revision is not None and revision[0].get_branch() is not None:
-            b = Branch.open(revision[0].get_branch())
-        b.lock_read()
-        try:
-            return self._run(tree, b, relpath, filename, revision,
-                name_from_revision)
+                                         " one revision specifier")
+        tree, branch, relpath = \
+            bzrdir.BzrDir.open_containing_tree_or_branch(filename)
+        branch.lock_read()
+        try:
+            return self._run(tree, branch, relpath, filename, revision,
+                             name_from_revision)
         finally:
-            b.unlock()
+            branch.unlock()
 
     def _run(self, tree, b, relpath, filename, revision, name_from_revision):
         if tree is None:

=== modified file 'bzrlib/tests/blackbox/test_cat.py'
--- bzrlib/tests/blackbox/test_cat.py	2007-09-04 03:23:59 +0000
+++ bzrlib/tests/blackbox/test_cat.py	2007-12-01 11:43:56 +0000
@@ -20,6 +20,7 @@
 """
 
 import os
+import sys
 
 from bzrlib.tests.blackbox import TestCaseWithTransport
 
@@ -128,3 +129,9 @@
         out, err = self.run_bzr_subprocess(['cat', url])
         self.assertEqual('contents of README\n', out)
 
+    def test_cat_nonexistant_branch(self):
+        if sys.platform == "win32":
+            location = "C:/i/do/not/exist"
+        else:
+            location = "/i/do/not/exist"
+        self.run_bzr_error(['^bzr: ERROR: Not a branch'], ['cat', location])

